@@ -1,3 +1,5 @@
+import sys
+
 import tensorflow as tf
 
 
@@ -5,6 +7,6 @@ def logits2pred(logits: tf.Tensor, activation: str) -> tf.Tensor:
     if isinstance(logits, tf.RaggedTensor):
         fill_value = 0
         if activation in ("sigmoid", "softmax"):
-            fill_value = -1e12
+            fill_value = logits.dtype.min
         logits = logits.to_tensor(fill_value)
     return tf.keras.activations.get(activation)(logits)
\ No newline at end of file
