@@ -11,7 +11,6 @@ import pandas as pd
 from tabulate import tabulate
 
 import tensorflow as tf
-from tensorflow.python.keras.utils.generic_utils import DisableSharedObjectScope
 
 import sknlp
 from sknlp.callbacks import default_supervised_model_callbacks
@@ -116,9 +115,10 @@ class BaseNLPModel:
             inputs=self.get_inputs(), outputs=self.get_outputs(), name=self.name
         )
         self._built = True
+        self.build_inference_model()
 
     def build_inference_model(self) -> tf.keras.Model:
-        return self._model
+        self._inference_model = self._model
 
     def build_encoding_layer(
         self, inputs: tf.Tensor | list[tf.Tensor]
@@ -327,7 +327,7 @@ class BaseNLPModel:
             callbacks=callbacks,
             verbose=verbose,
         )
-        self._inference_model = self.build_inference_model()
+        self.build_inference_model()
 
     def predict(
         self,
@@ -380,11 +380,10 @@ class BaseNLPModel:
         with open(os.path.join(directory, "vocab.json")) as f:
             vocab = Vocab.from_json(f.read())
         module = cls.from_config({"vocab": vocab, **meta})
-        with DisableSharedObjectScope():
-            module._model = tf.keras.models.load_model(
-                os.path.join(directory, cls._get_model_filename(epoch=epoch))
-            )
-            module._built = True
+        module._model = tf.keras.models.load_model(
+            os.path.join(directory, cls._get_model_filename(epoch=epoch))
+        )
+        module._built = True
         return module
 
     def export(self, directory: str, name: str, version: str = "0") -> None:
