@@ -21,12 +21,13 @@ from ..text2vec import Text2vec
 
 class DeepClassifier(SupervisedNLPModel):
     dataset_class = ClassificationDataset
-    dataset_args = ["is_multilabel"]
+    dataset_args = ["is_multilabel", "is_pair_text"]
 
     def __init__(
         self,
         classes: Sequence[str],
         is_multilabel: bool = True,
+        is_pair_text: bool = False,
         max_sequence_length: Optional[int] = None,
         num_fc_layers: int = 2,
         fc_hidden_size: int = 256,
@@ -48,7 +49,8 @@ class DeepClassifier(SupervisedNLPModel):
             task="classification",
             **kwargs,
         )
-        self._is_multilabel = is_multilabel
+        self._is_pair_text = is_pair_text
+        self._is_multilabel = is_multilabel and not is_pair_text
         self._loss = loss
         self._loss_kwargs = loss_kwargs
         self.num_fc_layers = num_fc_layers
@@ -59,22 +61,37 @@ class DeepClassifier(SupervisedNLPModel):
     def is_multilabel(self) -> bool:
         return self._is_multilabel
 
+    @property
+    def is_pair_text(self) -> bool:
+        return self._is_pair_text
+
     @property
     def thresholds(self) -> list[float]:
         _thresholds = [0.5 for _ in range(self.num_classes)]
-        _kthresholds: Optional[dict[str, float]] = self.prediction_kwargs.get(
+        class_thresholds: Optional[dict[str, float]] = self._inference_kwargs.get(
             "thresholds", None
         )
-        if _kthresholds is not None:
-            for c, t in _kthresholds.items():
+        if class_thresholds is not None:
+            for c, t in class_thresholds.items():
                 _thresholds[self.class2idx(c)] = t
         return _thresholds
 
     @thresholds.setter
-    def thresholds(self, thresholds: list[float]) -> None:
-        if len(thresholds) != self.num_classes:
-            raise ValueError(f"类别数为{self.num_classes}, 但thresholds长度为{len(thresholds)}")
-        self.prediction_kwargs["thresholds"] = dict(zip(self.classes, thresholds))
+    def thresholds(self, thresholds: Union[list[float], dict[str, float]]) -> None:
+        if (
+            isinstance(thresholds, list)
+            and len(thresholds) != self.num_classes
+            and len(thresholds) - 1 != self.num_classes
+        ):
+            raise ValueError(
+                f"类别数为{self.num_classes - 1}(不含NULL类别), "
+                f"但`thresholds`长度为{len(thresholds)}."
+            )
+        elif isinstance(thresholds, dict):
+            _thresholds = self.thresholds
+            for c, t in thresholds.items():
+                _thresholds[self.class2idx(c)] = t
+        self._inference_kwargs["thresholds"] = dict(zip(self.classes[1:], thresholds))
 
     def get_loss(self, *args, **kwargs) -> list[tf.keras.losses.Loss]:
         if self.is_multilabel:
@@ -111,7 +128,7 @@ class DeepClassifier(SupervisedNLPModel):
 
     def predict_proba(
         self,
-        X: Sequence[str] = None,
+        X: Sequence[Union[Sequence[str], Sequence[tuple[str, str]]]] = None,
         *,
         dataset: ClassificationDataset = None,
         batch_size: int = 128,
@@ -121,7 +138,7 @@ class DeepClassifier(SupervisedNLPModel):
 
     def predict(
         self,
-        X: Sequence[str] = None,
+        X: Sequence[Union[Sequence[str], Sequence[tuple[str, str]]]] = None,
         *,
         dataset: ClassificationDataset = None,
         thresholds: Union[float, list[float], None] = None,
@@ -140,14 +157,14 @@ class DeepClassifier(SupervisedNLPModel):
 
     def score(
         self,
-        X: Sequence[str] = None,
+        X: Sequence[Union[Sequence[str], Sequence[tuple[str, str]]]] = None,
         y: Union[Sequence[Sequence[str]], Sequence[str]] = None,
         *,
         dataset: ClassificationDataset = None,
         thresholds: Union[float, list[float], None] = None,
         batch_size: int = 128,
     ) -> pd.DataFrame:
-        dataset = self.prepare_dataset(X, y, dataset)
+        dataset = self.prepare_dataset(X, y, dataset, evaluation=True)
         predictions = self.predict(
             dataset=dataset, thresholds=thresholds, batch_size=batch_size
         )
@@ -161,6 +178,7 @@ class DeepClassifier(SupervisedNLPModel):
         return {
             **super().get_config(),
             "is_multilabel": self.is_multilabel,
+            "is_pair_text": self.is_pair_text,
         }
 
     @classmethod
