@@ -1,4 +1,4 @@
 from .file import make_tarball
 
 
-__all__ = ['make_tarball']
+__all__ = ["make_tarball"]
